#!/bin/sh

set -eo pipefail

# This scripts is a helper to convert PEM certificates and key
# to PKCS12 which ZooKeeper expects
#
# To use it, the following env vars to be set :
# ZK_SRV_KEY_FILE : the path of the PEM private key (must exists)
# ZK_SRV_CERT_FILE : the path of the PEM certificate (must exists)
# (both ZK_SRV_KEY_FILE and ZK_SRV_CERT_FILE can refer to the same file if it contains both)
# ZK_SRV_P12_FILE : the path of the PKCS12 bundle to create

if [ -n "${ZK_SRV_KEY_FILE}" -a -f "${ZK_SRV_KEY_FILE}" -a -n "${ZK_SRV_CERT_FILE}" -a -f "${ZK_SRV_CERT_FILE}" -a -n "${ZK_SRV_P12_FILE}" ]; then
  if [ ! -f "${ZK_SRV_P12_FILE}" -o "${ZK_SRV_KEY_FILE}" -nt "${ZK_SRV_P12_FILE}" ]; then
    echo "Creating ${ZK_SRV_P12_FILE} (from ${ZK_SRV_CERT_FILE}/${ZK_SRV_KEY_FILE})"
    openssl pkcs12 -export -out ${ZK_SRV_P12_FILE} -in ${ZK_SRV_CERT_FILE} -inkey ${ZK_SRV_KEY_FILE} -passout pass:password
    chmod 640 ${ZK_SRV_P12_FILE}
  else
    echo "${ZK_SRV_P12_FILE} already exists and is newer than ${ZK_SRV_KEY_FILE}"
  fi
fi

# Now same for the root cert/key
# ZK_ROOT_KEY_FILE : the path of the PEM private key (must exists)
# ZK_ROOT_CERT_FILE : the path of the PEM certificate (must exists)
# (both ZK_ROOT_KEY_FILE and ZK_ROOT_CERT_FILE can refer to the same file if it contains both)
# ZK_ROOT_P12_FILE : the path of the PKCS12 bundle to create

if [ -n "${ZK_ROOT_KEY_FILE}" -a -f "${ZK_ROOT_KEY_FILE}" -a -n "${ZK_ROOT_CERT_FILE}" -a -f "${ZK_ROOT_CERT_FILE}" -a -n "${ZK_ROOT_P12_FILE}" ]; then
  if [ ! -f "${ZK_ROOT_P12_FILE}" -o "${ZK_ROOT_KEY_FILE}" -nt "${ZK_ROOT_P12_FILE}" ]; then
    echo "Creating ${ZK_ROOT_P12_FILE} (from ${ZK_ROOT_CERT_FILE}/${ZK_ROOT_KEY_FILE})"
    openssl pkcs12 -export -out ${ZK_ROOT_P12_FILE} -in ${ZK_ROOT_CERT_FILE} -inkey ${ZK_ROOT_KEY_FILE} -passout pass:password
    chmod 640 ${ZK_ROOT_P12_FILE}
  else
    echo "${ZK_ROOT_P12_FILE} already exists and is newer than ${ZK_ROOT_KEY_FILE}"
  fi
fi
